'use strict';

const fs = require('fs');
const path = require('path');
const {envParse} = require('./env');
const loggerLeverls = require('./level');

const configFile = path.join(__dirname, '../../../.logrc');

module.exports = {
    baseConfig: {
        // common
        name: 'root',
        loggerLeverls,
        baseLevel: 'trace',
        timePattern: 'YYYY-MM-DD HH:mm:ss.SSS',
        // console
        console: true,
        level: 'info',
        // rotate
        rotate: true,
        dailyLevel: 'trace',
        datePattern: 'YYYY-MM-DD',
        zippedArchive: false,
        toFilename: name => `${name}.%DATE%.log`,
        dirname: path.join(__dirname, '../../../log'),
        stream: null,
        maxSize: null,
        maxFiles: '30d',
    },

    rcConfig: fs.existsSync(configFile)
        ? (() => {
              try {
                  return JSON.parse(fs.readFileSync(configFile));
              } catch (err) {
                  return {};
              }
          })()
        : {},

    processConfig: envParse({
        name: 'LOGGER',
        baseLevel: 'LOG_BASE_LEVEL',
        timePattern: 'LOG_TIME',
        console: 'CONSOLE#b',
        level: 'LOG_LEVEL',
        rotate: 'ROTATE#b',
        dailyLevel: 'LOG_DAILY_LEVEL',
        datePattern: 'LOG_DATE',
        zippedArchive: 'LOG_ZIP#b',
        dirname: 'LOG_DIR',
        maxSize: 'LOG_MAX_SIZE',
        maxFiles: 'LOG_MAX_FILES',
    }),
};
