'use strict';

const _ = require('lodash');

module.exports = {
    envParse(schema, ENV = process.env) {
        const branches = [
            getFormatter(
                ENV,
                '#b',
                str =>
                    str === 'true' ? true : str === 'false' ? false : undefined,
            ),
            getFormatter(ENV, '#i', parseInt),
            getFormatter(ENV, '#f', parseFloat),
            getFormatter(ENV, '#d', str => new Date(str)),
            [
                args => _.isArray(args) && _.isFunction(args[1]),
                args => {
                    const val = ENV[args[0]];
                    return _.isUndefined(val) ? undefined : args[1](val);
                },
            ],
            key => ENV[key],
        ];
        const getEnvVal = key => dispatch(branches, key);
        const env = {};
        _.each(schema, (val, key) => {
            env[key] = getEnvVal(val);
        });
        return env;
    },
    dispatch,
};

function dispatch(branches, ...args) {
    for (const branch of branches.slice(0, -1)) {
        const [match, action] = branch;
        if (match(...args)) return action(...args);
    }
    return branches.slice(-1)[0](...args);
}

function getFormatter(env, ext, formatter) {
    return [
        str => _.isString(str) && str.endsWith(ext),
        str => {
            const val = env[str.match(`(.*)${ext}`)[1]];
            return _.isUndefined(val) ? undefined : formatter(val);
        },
    ];
}
