'use strict';

const chalk = require('chalk');
const stringfiy = require('fast-safe-stringify');
const moment = require('moment');
const {MESSAGE} = require('triple-beam');
const {format} = require('winston');

function formatMessage(message) {
    if (!message || !message.constructor) return message;

    const messageType = message.constructor.name;
    switch (messageType) {
        case 'String':
            return message;
        case 'Object':
            return stringfiy(message);
        default:
            return messageType + ' ' + stringfiy(message);
    }
}

module.exports = {
    colorize: format((info, opts) => {
        const color = opts.loggerLeverls.colors[info.level];
        info[MESSAGE] = chalk[color](info[MESSAGE]);
        return info;
    }),

    pretty: format((info, opts) => {
        const timestamp = moment(info.timestamp).format(opts.timePattern);
        const level = info.level.toUpperCase().padEnd(5);
        const name = opts.name;
        const message = formatMessage(info.message);
        info[MESSAGE] = `[${timestamp}] [${level}] [${name}] - ${message}`;
        return info;
    }),
};
